#
# spec file for package python-cassandra-driver
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-cassandra-driver
Version:        3.15.0
Release:        2.1
Summary:        Python driver for Cassandra
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            http://github.com/datastax/python-driver
Source:         https://files.pythonhosted.org/packages/source/c/cassandra-driver/cassandra-driver-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six} >= 1.6
BuildRequires:  python-rpm-macros
BuildRequires:  python2-futures
Requires:       python-Cython
Requires:       python-blist
Requires:       python-six >= 1.6
# test requirements
#BuildRequires:  %{python_module PyYAML}
#BuildRequires:  %{python_module mock}
#BuildRequires:  %{python_module nose}
#BuildRequires:  %{python_module pytz}
#BuildRequires:  %{python_module sure}
%ifpython2
Requires:       python2-futures
%endif
%python_subpackages

%description
A tunable Python client library for Apache Cassandra (1.2+) and
DataStax Enterprise (3.1+) using exclusively Cassandra's binary
protocol and Cassandra Query Language v3.
A list of features may be found at https://github.com/datastax/python-driver#features .

The driver supports Python 2.7, 3.3, 3.4, 3.5, and 3.6.

%prep
%setup -q -n cassandra-driver-%{version}

%build
export CFLAGS="%{optflags}"
export CASS_DRIVER_NO_EXTENSIONS=1
%python_build

%install
export CASS_DRIVER_NO_EXTENSIONS=1
%python_install

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/*

%changelog
* Sat Sep  1 2018 arun@gmx.de
- update to version 3.15.0:
  * Features
    + Parse Virtual Keyspace Metadata (PYTHON-992)
  * Bug Fixes
    + Tokenmap.get_replicas returns the wrong value if token coincides
    with the end of the range (PYTHON-978)
    + Python Driver fails with "more than 255 arguments" python
    exception when > 255 columns specified in query response
    (PYTHON-893)
    + Hang in
    integration.standard.test_cluster.ClusterTests.test_set_keyspace_twice
    (PYTHON-998)
    + Asyncore reactors should use a global variable instead of a
    class variable for the event loop (PYTHON-697)
  * Other
    + Use global variable for libev loops so it can be subclassed
    (PYTHON-973)
    + Update SchemaParser for V4 (PYTHON-1006)
    + Bump Cython dependency version to 0.28 (PYTHON-1012)
* Wed Jun 13 2018 jengelh@inai.de
- Trim marketing wording from description.
* Sun May  6 2018 arun@gmx.de
- update to version 3.14.0:
  * Features
    + Add one() function to the ResultSet API (PYTHON-947)
    + Create an utility function to fetch concurrently many keys from
    the same replica (PYTHON-647)
    + Allow filter queries with fields that have an index managed
    outside of cqlengine (PYTHON-966)
    + Twisted SSL Support (PYTHON-343)
    + Support IS NOT NULL operator in cqlengine (PYTHON-968)
  * Other
    + Fix Broken Links in Docs (PYTHON-916)
    + Reevaluate MONKEY_PATCH_LOOP in test codebase (PYTHON-903)
    + Remove CASS_SERVER_VERSION and replace it for CASSANDRA_VERSION
    in tests (PYTHON-910)
    + Refactor CASSANDRA_VERSION to a some kind of version object
    (PYTHON-915)
    + Log warning when driver configures an authenticator, but server
    does not request authentication (PYTHON-940)
    + Warn users when using the deprecated
    Session.default_consistency_level (PYTHON-953)
    + Add DSE smoke test to OSS driver tests (PYTHON-894)
    + Document long compilation times and workarounds (PYTHON-868)
    + Improve error for batch WriteTimeouts (PYTHON-941)
    + Deprecate ResultSet indexing (PYTHON-945)
* Sun Feb  4 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 3.13.0:
  * Features
    + cqlengine: LIKE filter operator (PYTHON-512)
    + Support cassandra.query.BatchType with cqlengine BatchQuery
    (PYTHON-888)
  * Bug Fixes
    + AttributeError: 'NoneType' object has no attribute 'add_timer'
    (PYTHON-862)
    + Support retry_policy in PreparedStatement (PYTHON-861)
    + __del__ method in Session is throwing an exception (PYTHON-813)
    + LZ4 import issue with recent versions (PYTHON-897)
    + ResponseFuture._connection can be None when returning request_id
    (PYTHON-853)
  * Other
    + cqlengine: avoid warning when unregistering connection on
    shutdown (PYTHON-865)
    + Fix DeprecationWarning of log.warn (PYTHON-846)
    + Fix example_mapper.py for python3 (PYTHON-860)
    + Possible deadlock on cassandra.concurrent.execute_concurrent
    (PYTHON-768)
    + Add some known deprecated warnings for 4.x (PYTHON-877)
    + Remove copyright dates from copyright notices (PYTHON-863)
    + Remove "Experimental" tag from execution profiles documentation
    (PYTHON-840)
    + request_timer metrics descriptions are slightly incorrect
    (PYTHON-885)
    + Remove "Experimental" tag from cqlengine connections
    documentation (PYTHON-892)
    + Set in documentation default consistency for operations is
    LOCAL_ONE (PYTHON-901)
* Tue Nov  7 2017 arun@gmx.de
- update to version 3.12.0:
  * Features
    + Send keyspace in QUERY, PREPARE, and BATCH messages (PYTHON-678)
    + Add IPv4Address/IPv6Address support for inet types (PYTHON-751)
    + WriteType.CDC and VIEW missing (PYTHON-794)
    + Warn on Cluster init if contact points are specified but LBP
    isn't (legacy mode) (PYTHON-812)
    + Warn on Cluster init if contact points are specified but LBP
    isn't (exection profile mode) (PYTHON-838)
    + Include hash of result set metadata in prepared stmt id
    (PYTHON-808)
    + Add NO_COMPACT startup option (PYTHON-839)
    + Add new exception type for CDC (PYTHON-837)
  * Bug Fixes
    + Both _set_final_exception/result called for the same
    ResponseFuture (PYTHON-630)
    + Use of DCAwareRoundRobinPolicy raises NoHostAvailable exception
    (PYTHON-781)
    + Not create two sessions by default in CQLEngine (PYTHON-814)
    + Bug when subclassing AyncoreConnection (PYTHON-827)
    + Error at cleanup when closing the asyncore connections
    (PYTHON-829)
    + Fix sites where sessions can change during iteration
    (PYTHON-793)
    + cqlengine: allow min_length=0 for Ascii and Text column types
    (PYTHON-735)
    + Rare exception when "sys.exit(0)" after query timeouts
    (PYTHON-752)
    + Dont set the session keyspace when preparing statements
    (PYTHON-843)
    + Use of DCAwareRoundRobinPolicy raises NoHostAvailable exception
    (PYTHON-781)
  * Other
    + Remove DeprecationWarning when using WhiteListRoundRobinPolicy
    (PYTHON-810)
    + Bump Cython dependency version to 0.27 (PYTHON-833)
* Wed Oct  4 2017 arun@gmx.de
- specfile:
  * fixed source url
  * updated description
* Tue Oct  3 2017 arun@gmx.de
- update to version 3.11.0:
  * Features
    + Add idle_heartbeat_timeout cluster option to tune how long to
    wait for heartbeat responses. (PYTHON-762)
    + Add HostFilterPolicy (PYTHON-761)
  * Bug Fixes
    + is_idempotent flag is not propagated from PreparedStatement to
    BoundStatement (PYTHON-736)
    + Fix asyncore hang on exit (PYTHON-767)
    + Driver takes several minutes to remove a bad host from session
    (PYTHON-762)
    + Installation doesn't always fall back to no cython in Windows
    (PYTHON-763)
    + Avoid to replace a connection that is supposed to shutdown
    (PYTHON-772)
    + request_ids may not be returned to the pool (PYTHON-739)
    + Fix murmur3 on big-endian systems (PYTHON-653)
    + Ensure unused connections are closed if a Session is deleted by
    the GC (PYTHON-774)
    + Fix .values_list by using db names internally (cqlengine)
    (PYTHON-785)
  * Other
    + Bump Cython dependency version to 0.25.2 (PYTHON-754)
    + Fix DeprecationWarning when using lz4 (PYTHON-769)
    + Deprecate WhiteListRoundRobinPolicy (PYTHON-759)
    + Improve upgrade guide for materializing pages (PYTHON-464)
    + Documentation for time/date specifies timestamp inupt as
    microseconds (PYTHON-717)
    + Point to DSA Slack, not IRC, in docs index
- changes from version 3.10.0:
  * Features
    + Add Duration type to cqlengine (PYTHON-750)
    + Community PR review: Raise error on primary key update only if
    its value changed (PYTHON-705)
    + get_query_trace() contract is ambiguous (PYTHON-196)
  * Bug Fixes
    + Queries using speculative execution policy timeout prematurely
    (PYTHON-755)
    + Fix map where results are not consumed (PYTHON-749)
    + Driver fails to encode Duration's with large values (PYTHON-747)
    + UDT values are not updated correctly in CQLEngine (PYTHON-743)
    + UDT types are not validated in CQLEngine (PYTHON-742)
    + to_python is not implemented for types columns.Type and
    columns.Date in CQLEngine (PYTHON-741)
    + Clients spin infinitely trying to connect to a host that is
    drained (PYTHON-734)
    + Resulset.get_query_trace returns empty trace sometimes
    (PYTHON-730)
    + Memory grows and doesn't get removed (PYTHON-720)
    + Fix RuntimeError caused by change dict size during iteration
    (PYTHON-708)
    + fix ExponentialReconnectionPolicy may throw OverflowError
    problem (PYTHON-707)
    + Avoid using nonexistent prepared statement in ResponseFuture
    (PYTHON-706)
  * Other
    + Update README (PYTHON-746)
    + Test python versions 3.5 and 3.6 (PYTHON-737)
    + Docs Warning About Prepare "select *" (PYTHON-626)
    + Increase Coverage in CqlEngine Test Suite (PYTHON-505)
    + Example SSL connection code does not verify server certificates
    (PYTHON-469)
- changes from version 3.9.0:
  * Features
    + cqlengine: remove elements by key from a map (PYTHON-688)
  * Bug Fixes
    + improve error handling when connecting to non-existent keyspace
    (PYTHON-665)
    + Sockets associated with sessions not getting cleaned up on
    session.shutdown() (PYTHON-673)
    + rare flake on
    integration.standard.test_cluster.ClusterTests.test_clone_shared_lbp
    (PYTHON-727)
    + MontonicTimestampGenerator.__init__ ignores class defaults
    (PYTHON-728)
    + race where callback or errback for request may not be called
    (PYTHON-733)
    + cqlengine: model.update() should not update columns with a
    default value that hasn't changed (PYTHON-657)
    + cqlengine: field value manager's explicit flag is True when
    queried back from cassandra (PYTHON-719)
  * Other
    + Connection not closed in example_mapper (PYTHON-723)
    + Remove mention of pre-2.0 C* versions from OSS 3.0+ docs
    (PYTHON-710)
- changes from version 3.8.1:
  * Bug Fixes
    + implement __le__/__ge__/__ne__ on some custom types (PYTHON-714)
    + Fix bug in eventlet and gevent reactors that could cause hangs
    (PYTHON-721)
    + Fix DecimalType regression (PYTHON-724)
- changes from version 3.8.0:
  * Features
    + Quote index names in metadata CQL generation (PYTHON-616)
    + On column deserialization failure, keep error message consistent
    between python and cython (PYTHON-631)
    + TokenAwarePolicy always sends requests to the same replica for a
    given key (PYTHON-643)
    + Added cql types to result set (PYTHON-648)
    + Add __len__ to BatchStatement (PYTHON-650)
    + Duration Type for Cassandra (PYTHON-655)
    + Send flags with PREPARE message in v5 (PYTHON-684)
  * Bug Fixes
    + Potential Timing issue if application exits prior to session
    pool initialization (PYTHON-636)
    + "Host X.X.X.X has been marked down" without any exceptions
    (PYTHON-640)
    + NoHostAvailable or OperationTimedOut when using
    execute_concurrent with a generator that inserts into more than
    one table (PYTHON-642)
    + ResponseFuture creates Timers and don't cancel them even when
    result is received which leads to memory leaks (PYTHON-644)
    + Driver cannot connect to Cassandra version > 3 (PYTHON-646)
    + Unable to import model using UserType without setuping
    connection since 3.7 (PYTHON-649)
    + Don't prepare queries on ignored hosts on_up (PYTHON-669)
    + Sockets associated with sessions not getting cleaned up on
    session.shutdown() (PYTHON-673)
    + Make client timestamps strictly monotonic (PYTHON-676)
    + cassandra.cqlengine.connection.register_connection broken when
    hosts=None (PYTHON-692)
  * Other
    + Create a cqlengine doc section explaining None semantics
    (PYTHON-623)
    + Resolve warnings in documentation generation (PYTHON-645)
    + Cython dependency (PYTHON-686)
    + Drop Support for Python 2.6 (PYTHON-690)
* Tue Oct  3 2017 arun@gmx.de
- update to single spec
- commented out test-requirements, since tests are not run at the
  moment
* Mon Jan 16 2017 dmueller@suse.com
- Initial package (3.7.1)
